/****************************************************************************
 *   $Id:: uart.h 6172 2011-01-13 18:22:51Z usb00423                        $
 *   Project: NXP LPC11xx software example
 *
 *   Description:
 *     This file contains definition and prototype for UART configuration.
 *
 ****************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * NXP Semiconductors assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. NXP Semiconductors
 * reserves the right to make changes in the software without
 * notification. NXP Semiconductors also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
****************************************************************************/
#ifndef __UART_H 
#define __UART_H

#define RS485_ENABLED   0
#define TX_INTERRUPT    1		/* 0 if TX uses polling, 1 interrupt driven. */
#define MODEM_TEST      0

#define IER_RBR         (0x01<<0)
#define IER_THRE        (0x01<<1)
#define IER_RLS         (0x01<<2)

#define IIR_PEND        0x01
#define IIR_RLS         0x03
#define IIR_RDA         0x02
#define IIR_CTI         0x06
#define IIR_THRE        0x01

#define LSR_RDR         (0x01<<0)
#define LSR_OE          (0x01<<1)
#define LSR_PE          (0x01<<2)
#define LSR_FE          (0x01<<3)
#define LSR_BI          (0x01<<4)
#define LSR_THRE        (0x01<<5)
#define LSR_TEMT        (0x01<<6)
#define LSR_RXFE        (0x01<<7)

#define USART_CFG_SYNCEN         (1 << 0)
#define USART_CFG_SYNCMST        (1 << 1)
#define USART_CFG_CLKPOL         (1 << 2)
#define USART_CFG_DATALEN(d)     (((d) - 5) << 0)
#define USART_CFG_PARITY_EVEN    (1 << 4)
#define USART_CFG_PARITY_ENABLE  (1 << 3)
#define USART_CFG_STOPLEN(s)     (((s) - 1) << 2)
#define USART_CFG_PARITY_EVEN_P   4
#define USART_CTRL_TXBRKEN_P      6
#define USART_STAT_TXRDY          (1<<5)
#define USART_STAT_RXRDY          (1<<0)
#define USART_DLAB               (1<<7)

#define BUFSIZE         0x40

/* RS485 mode definition. */
#define RS485_NMMEN		(0x1<<0)
#define RS485_RXDIS		(0x1<<1)
#define RS485_AADEN		(0x1<<2)
#define RS485_SEL             (0x1<<3)
#define RS485_DCTRL		(0x1<<4)
#define RS485_OINV		(0x1<<5)

void ModemInit( void );
int UARTInit(uint32_t baudrate,int uclk);
void USART_IRQHandler(void);
void UARTSend(uint8_t *BufferPtr);
void print_string( uint8_t *str_ptr );
int UARTformat(int bits, int parity, int stop_bits );
uint8_t get_key();

#endif /* end __UART_H */
/*****************************************************************************
**                            End Of File
******************************************************************************/
